Documentation
¶
Index ¶
- Variables
- func IsDir(from string) bool
- func IsFile(from string) bool
- func IsHTTP(from string) bool
- func IsOCI(from string) bool
- func IsRegistryScheme(s Schema) bool
- func IsS3(from string) bool
- type Reference
- func (r Reference) Descriptor() ocispecv1.Descriptor
- func (r Reference) IsZero() bool
- func (r Reference) Merge(ref Reference) Reference
- func (r Reference) RepoReference() string
- func (r Reference) String() string
- func (r Reference) URL(plainHttp bool) Url
- func (r Reference) WithDescriptor(desc ocispecv1.Descriptor) Reference
- type Schema
- type Url
Constants ¶
This section is empty.
Variables ¶
var ( // ErrInvalid is returned when there is an invalid reference ErrInvalid = errors.New("invalid reference") ErrSchemeRequired = errors.New("scheme required") ErrSchemeUnsupported = errors.New("scheme unsupported") // ErrHostnameRequired is returned when the hostname is required ErrHostnameRequired = errors.New("hostname required") )
Functions ¶
func IsRegistryScheme ¶
Types ¶
type Reference ¶
type Reference struct {
Scheme Schema
Host string
Path string
Ref string
// contains filtered or unexported fields
}
func ParseRegistryReference ¶
func (Reference) Descriptor ¶
func (r Reference) Descriptor() ocispecv1.Descriptor
func (Reference) RepoReference ¶
func (Reference) WithDescriptor ¶
func (r Reference) WithDescriptor(desc ocispecv1.Descriptor) Reference
Click to show internal directories.
Click to hide internal directories.